(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     35546,       1104]
NotebookOptionsPosition[     33272,       1026]
NotebookOutlinePosition[     33608,       1041]
CellTagsIndexPosition[     33565,       1038]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Zweidimensionales Ising-Modell", "Subtitle",
 FontSize->30],

Cell["\<\
\[Copyright] Prof. Dr. J\[UDoubleDot]rgen Schnack, Herbstakademie 2008\
\>", "Subsubtitle",
 CellChangeTimes->{{3.428927225154994*^9, 3.428927239429668*^9}},
 FontSize->20],

Cell["\<\
Ising-Modell auf einem Quadratgitter der Gr\[ODoubleDot]\[SZ]e NMax * NMax.
Das Programm durchl\[ADoubleDot]uft mehrere Temperaturen und berechnet die \
Magnetisierung.
Die Wechselwirkung der Spins ist 1.\
\>", "Subsubtitle",
 FontSize->18],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix", "Section",
 FontSize->20],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NMax", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NMaxSq", "=", 
   SuperscriptBox["NMax", "2"]}], ";"}]}], "Input",
 FontSize->16],

Cell[TextData[{
 "Spins sind wie folgt abgez\[ADoubleDot]hlt:\n",
 Cell[BoxData[
  RowBox[{"(", GridBox[{
     {"1", "2", "3"},
     {"4", "5", "6"},
     {"7", "8", "9"}
    }], ")"}]]]
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
Hilfsfeld, in dem die Spinnummer in den Platz umgerechnet wird\
\>", "Subsection",
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Platz", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"IntegerPart", "[", 
        FractionBox[
         RowBox[{"k", "-", "1"}], "NMax"], "]"}], "+", "1"}], ",", 
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"k", "-", "1"}], ",", "NMax"}], "]"}], "+", "1"}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "NMaxSq"}], "}"}]}], "]"}]}]], "Input",
 FontSize->16],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "10"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.40057234245576*^9},
 FontSize->16]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wechselwirkungsmatrix JMat", "Subsection",
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{"JMat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "NMaxSq"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "NMaxSq"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i1", "=", "1"}], ",", 
    RowBox[{"i1", "<", 
     RowBox[{"NMax", "+", "1"}]}], ",", 
    RowBox[{"i1", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j1", "=", "1"}], ",", 
      RowBox[{"j1", "<", 
       RowBox[{"NMax", "+", "1"}]}], ",", 
      RowBox[{"j1", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i2", "=", "1"}], ",", 
        RowBox[{"i2", "<", 
         RowBox[{"NMax", "+", "1"}]}], ",", 
        RowBox[{"i2", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j2", "=", "1"}], ",", 
          RowBox[{"j2", "<", 
           RowBox[{"NMax", "+", "1"}]}], ",", 
          RowBox[{"j2", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{
             "i1", ",", "\"\< \>\"", ",", "i2", ",", "\"\< \>\"", ",", "j1", 
              ",", "\"\< \>\"", ",", "j2", ",", "\"\< \>\"", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"i1", "-", "1"}], ")"}], "*", "NMax"}], "+", "j1"}], 
              ",", "\"\< \>\"", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"i2", "-", "1"}], ")"}], "*", "NMax"}], "+", 
               "j2"}]}], "]"}], ";"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"i1", "-", "i2"}], "]"}], ",", "NMax"}], "]"}], 
               "\[Equal]", "1"}], "&&", 
              RowBox[{"j1", "\[Equal]", "j2"}]}], ",", 
             RowBox[{
              RowBox[{"JMat", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i1", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j1"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i2", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j2"}]}], "]"}], "]"}], "=", "1"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"i1", "-", "i2"}], "]"}], ",", "NMax"}], "]"}], 
               "\[Equal]", 
               RowBox[{"NMax", "-", "1"}]}], "&&", 
              RowBox[{"j1", "\[Equal]", "j2"}]}], ",", 
             RowBox[{
              RowBox[{"JMat", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i1", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j1"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i2", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j2"}]}], "]"}], "]"}], "=", "1"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"j1", "-", "j2"}], "]"}], ",", "NMax"}], "]"}], 
               "\[Equal]", "1"}], "&&", 
              RowBox[{"i1", "\[Equal]", "i2"}]}], ",", 
             RowBox[{
              RowBox[{"JMat", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i1", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j1"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i2", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j2"}]}], "]"}], "]"}], "=", "1"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Mod", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"j1", "-", "j2"}], "]"}], ",", "NMax"}], "]"}], 
               "\[Equal]", 
               RowBox[{"NMax", "-", "1"}]}], "&&", 
              RowBox[{"i1", "\[Equal]", "i2"}]}], ",", 
             RowBox[{
              RowBox[{"JMat", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i1", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j1"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i2", "-", "1"}], ")"}], "*", "NMax"}], "+", 
                  "j2"}]}], "]"}], "]"}], "=", "1"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MatrixForm", "[", "JMat", "]"}], ";"}]}], "Input",
 FontSize->16]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ausgangszustand", "Section",
 FontSize->20],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spins", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"RandomInteger", "[", "]"}]}], "-", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "NMax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "NMax"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Spins0", "=", "Spins"}], ";"}], "\n", 
 TagBox["Spins",
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]}], "Input",
 FontSize->16],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.400572342720786*^9},
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Raster", "[", "Spins", "]"}], "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.400572283344161*^9, 3.400572300388842*^9}, {
  3.400572369143621*^9, 3.4005723729636497`*^9}, {3.400572503726062*^9, 
  3.400572504260178*^9}},
 FontSize->16],

Cell[BoxData[
 GraphicsBox[
  RasterBox[{{{0, 0, 1}, {0, 0, 1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 
   0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 0}}, {{0, 0, 1}, {0, 0, 1}, {0,
    0, 1}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {
   1, 0, 0}}, {{0, 0, 1}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {1, 0, 
   0}, {0, 0, 1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}}, {{1, 0, 0}, {1, 0, 0}, {0,
    0, 1}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {
   1, 0, 0}}, {{0, 0, 1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
   1}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}}, {{0, 0, 1}, {1, 0, 0}, {1,
    0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {
   1, 0, 0}}, {{0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {1, 0, 0}, {1, 0, 
   0}, {1, 0, 0}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}}, {{0, 0, 1}, {1, 0, 0}, {1,
    0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {1, 0, 0}, {
   1, 0, 0}}, {{1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {1, 0, 
   0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}}, {{1, 0, 0}, {1, 0, 0}, {0,
    0, 1}, {1, 0, 0}, {0, 0, 1}, {1, 0, 0}, {1, 0, 0}, {1, 0, 0}, {0, 0, 1}, {
   1, 0, 0}}}],
  AspectRatio->1]], "Output",
 CellChangeTimes->{
  3.400572343018672*^9, {3.400572479589203*^9, 3.400572505465077*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metropolis", "Section",
 FontSize->20],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MaxSweeps", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TSteps", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Magnetisierung", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.0", ",", "0.0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "TSteps"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 FontSize->16],

Cell["\<\
DeltaE=(ENeu-EAlt) ist zweimal die Summe, weil man -s_i*Summe-s_i*Summe hat.\
\>", "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"iT", "=", "1"}], ",", 
    RowBox[{"iT", "<", "21"}], ",", 
    RowBox[{"iT", "++"}], ",", 
    RowBox[{
     RowBox[{"T", "=", 
      RowBox[{"0.5`", " ", "iT"}]}], ";", 
     RowBox[{"Spins", "=", "Spins0"}], ";", 
     RowBox[{
      RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
       RowBox[{"iT", ",", "1"}], "\[RightDoubleBracket]"}], "=", "T"}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"Sweeps", "=", "1"}], ",", 
       RowBox[{"Sweeps", "<", 
        RowBox[{"MaxSweeps", "+", "1"}]}], ",", 
       RowBox[{"Sweeps", "++"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "<", 
          RowBox[{"NMaxSq", "+", "1"}]}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"DeltaE", "=", 
           RowBox[{"2", " ", 
            RowBox[{"Spins", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{"Platz", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"Platz", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], 
             "\[RightDoubleBracket]"}], " ", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"k", "=", "1"}], "NMaxSq"], 
             RowBox[{
              RowBox[{"JMat", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "k"}], "\[RightDoubleBracket]"}], " ", 
              RowBox[{"Spins", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "\[RightDoubleBracket]"}]}]}]}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"DeltaE", "\[LessEqual]", "0"}], ",", 
            RowBox[{
             RowBox[{"Spins", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"Platz", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"Platz", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], 
              "\[RightDoubleBracket]"}], "=", 
             RowBox[{"-", 
              RowBox[{"Spins", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"-", 
                 FractionBox["DeltaE", "T"]}]]}], ",", 
              RowBox[{
               RowBox[{"Spins", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"Platz", "\[LeftDoubleBracket]", 
                  RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"Platz", "\[LeftDoubleBracket]", 
                  RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{"-", 
                RowBox[{"Spins", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"Platz", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"Platz", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                 "\[RightDoubleBracket]"}]}]}]}], "]"}]}], "]"}], ";", 
          RowBox[{
           RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
            RowBox[{"iT", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
             RowBox[{"iT", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
            RowBox[{"Abs", "[", 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"k", "=", "1"}], "NMaxSq"], 
              RowBox[{"Spins", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                RowBox[{"Platz", "\[LeftDoubleBracket]", 
                 RowBox[{"k", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               "\[RightDoubleBracket]"}]}], "]"}]}]}]}]}], "]"}]}], "]"}], 
     ";", 
     RowBox[{
      RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
       RowBox[{"iT", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
      FractionBox[
       RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
        RowBox[{"iT", ",", "2"}], "\[RightDoubleBracket]"}], 
       RowBox[{"Sweeps", " ", "NMaxSq", " ", "NMaxSq"}]]}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{
       RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
        RowBox[{"iT", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       "\"\<  \>\"", ",", 
       RowBox[{"Magnetisierung", "\[LeftDoubleBracket]", 
        RowBox[{"iT", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}]}]}], 
   "]"}], ";"}]], "Input",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "0.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.9693425742574259`"}],
  SequenceForm[0.5, "  ", 0.9693425742574259],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572347543457*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.9681544554455447`"}],
  SequenceForm[1., "  ", 0.9681544554455447],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572351987051*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.9515148514851486`"}],
  SequenceForm[1.5, "  ", 0.9515148514851486],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572356518852*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.8521920792079208`"}],
  SequenceForm[2., "  ", 0.8521920792079208],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005723609577847`*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.4366297029702971`"}],
  SequenceForm[2.5, "  ", 0.4366297029702971],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572365440896*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.31552673267326736`"}],
  SequenceForm[3., "  ", 0.31552673267326736`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572369948498*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.21643366336633665`"}],
  SequenceForm[3.5, "  ", 0.21643366336633665`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572374448477*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1670930693069307`"}],
  SequenceForm[4., "  ", 0.1670930693069307],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005723789538727`*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1383782178217822`"}],
  SequenceForm[4.5, "  ", 0.1383782178217822],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572383593611*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1345762376237624`"}],
  SequenceForm[5., "  ", 0.1345762376237624],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005723909106903`*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.12270693069306932`"}],
  SequenceForm[5.5, "  ", 0.12270693069306932`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572392768012*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.10900990099009902`"}],
  SequenceForm[6., "  ", 0.10900990099009902`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572397309564*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1146950495049505`"}],
  SequenceForm[6.5, "  ", 0.1146950495049505],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005724018081837`*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1111960396039604`"}],
  SequenceForm[7., "  ", 0.1111960396039604],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572406283917*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.10814851485148516`"}],
  SequenceForm[7.5, "  ", 0.10814851485148516`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572410788726*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.11182970297029704`"}],
  SequenceForm[8., "  ", 0.11182970297029704`],
  Editable->False]], "Print",
 CellChangeTimes->{3.40057241529891*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.1111821782178218`"}],
  SequenceForm[8.5, "  ", 0.1111821782178218],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005724198489017`*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.10661782178217823`"}],
  SequenceForm[9., "  ", 0.10661782178217823`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572424352248*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9.5`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.11011683168316833`"}],
  SequenceForm[9.5, "  ", 0.11011683168316833`],
  Editable->False]], "Print",
 CellChangeTimes->{3.400572428858041*^9},
 FontSize->16],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "10.`", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
   "0.12007722772277228`"}],
  SequenceForm[10., "  ", 0.12007722772277228`],
  Editable->False]], "Print",
 CellChangeTimes->{3.4005724333440228`*^9},
 FontSize->16]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Magnetisierung", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Hue", "[", "0", "]"}], ",", 
      RowBox[{"PointSize", "[", "0.03`", "]"}]}], "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "18"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.400572326831629*^9, 3.400572329869341*^9}, {
  3.400572445810238*^9, 3.400572468728861*^9}},
 FontSize->16],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0], PointSize[0.03], 
    PointBox[{{0.5, 0.9693425742574259}, {1., 0.9681544554455447}, {1.5, 
     0.9515148514851486}, {2., 0.8521920792079208}, {2.5, 
     0.4366297029702971}, {3., 0.31552673267326736`}, {3.5, 
     0.21643366336633665`}, {4., 0.1670930693069307}, {4.5, 
     0.1383782178217822}, {5., 0.1345762376237624}, {5.5, 
     0.12270693069306932`}, {6., 0.10900990099009902`}, {6.5, 
     0.1146950495049505}, {7., 0.1111960396039604}, {7.5, 
     0.10814851485148516`}, {8., 0.11182970297029704`}, {8.5, 
     0.1111821782178218}, {9., 0.10661782178217823`}, {9.5, 
     0.11011683168316833`}, {10., 0.12007722772277228`}}]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 18},
  PlotRange->{{0, 10.5}, {0, 1.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.400572433867772*^9, 3.4005724701412773`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 65, 1, 52, "Subtitle"],
Cell[658, 26, 182, 4, 30, "Subsubtitle"],
Cell[843, 32, 250, 6, 66, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1118, 42, 55, 1, 67, "Section"],
Cell[1176, 45, 189, 6, 55, "Input"],
Cell[1368, 53, 213, 9, 89, "Text"],
Cell[CellGroupData[{
Cell[1606, 66, 107, 3, 38, "Subsection"],
Cell[CellGroupData[{
Cell[1738, 73, 500, 17, 54, "Input"],
Cell[2241, 92, 6029, 204, 192, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8319, 302, 63, 1, 38, "Subsection"],
Cell[8385, 305, 5875, 158, 352, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14309, 469, 49, 1, 67, "Section"],
Cell[CellGroupData[{
Cell[14383, 474, 518, 17, 72, "Input"],
Cell[14904, 493, 2506, 75, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17447, 573, 664, 18, 31, "Input"],
Cell[18114, 593, 1343, 20, 375, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19506, 619, 44, 1, 67, "Section"],
Cell[19553, 622, 435, 14, 72, "Input"],
Cell[19991, 638, 115, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[20131, 645, 5652, 124, 425, "Input"],
Cell[CellGroupData[{
Cell[25808, 773, 273, 8, 24, "Print"],
Cell[26084, 783, 271, 8, 24, "Print"],
Cell[26358, 793, 273, 8, 24, "Print"],
Cell[26634, 803, 273, 8, 24, "Print"],
Cell[26910, 813, 273, 8, 24, "Print"],
Cell[27186, 823, 274, 8, 24, "Print"],
Cell[27463, 833, 276, 8, 24, "Print"],
Cell[27742, 843, 273, 8, 24, "Print"],
Cell[28018, 853, 273, 8, 24, "Print"],
Cell[28294, 863, 273, 8, 24, "Print"],
Cell[28570, 873, 276, 8, 24, "Print"],
Cell[28849, 883, 274, 8, 24, "Print"],
Cell[29126, 893, 275, 8, 24, "Print"],
Cell[29404, 903, 271, 8, 24, "Print"],
Cell[29678, 913, 276, 8, 24, "Print"],
Cell[29957, 923, 273, 8, 24, "Print"],
Cell[30233, 933, 275, 8, 24, "Print"],
Cell[30511, 943, 274, 8, 24, "Print"],
Cell[30788, 953, 276, 8, 24, "Print"],
Cell[31067, 963, 278, 8, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31394, 977, 806, 22, 52, "Input"],
Cell[32203, 1001, 1029, 20, 242, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
